@@ -2,4 +2,7 @@ from surprisal.model import (
     AutoHuggingFaceModel,
     CausalHuggingFaceModel,
     MaskedHuggingFaceModel,
+    OpenAIModel,
 )
+
+from surprisal.interface import SurprisalQuantity
